pub struct GeneralConfig {Show 16 fields
pub listen_addr: String,
pub port: u16,
pub api_key: Option<String>,
pub incomplete_dir: PathBuf,
pub complete_dir: PathBuf,
pub data_dir: PathBuf,
pub speed_limit_bps: u64,
pub cache_size: u64,
pub log_level: String,
pub log_file: Option<PathBuf>,
pub history_retention: Option<usize>,
pub max_active_downloads: usize,
pub min_free_space_bytes: u64,
pub watch_dir: Option<PathBuf>,
pub rss_history_limit: Option<usize>,
pub direct_unpack: bool,
}Fields
listen_addr: StringHTTP API listen address
port: u16HTTP API port
api_key: Option<String>API key for authentication
incomplete_dir: PathBufDirectory for incomplete downloads
complete_dir: PathBufDirectory for completed downloads
data_dir: PathBufDirectory for application data (DB, logs)
speed_limit_bps: u64Download speed limit in bytes/sec (0 = unlimited)
cache_size: u64Article cache size in bytes
log_level: StringLog level
log_file: Option<PathBuf>Log file path (None = stdout only)
history_retention: Option<usize>History retention: how many NZBs to keep in history (None = keep all)
max_active_downloads: usizeMax number of NZBs downloading simultaneously (default 1)
min_free_space_bytes: u64Minimum free disk space in bytes before pausing downloads (default 1 GB)
watch_dir: Option<PathBuf>Directory to watch for new .nzb files to auto-enqueue
rss_history_limit: Option<usize>RSS feed history limit: how many feed items to keep (None = keep all, default 500)
direct_unpack: boolBegin extracting RAR volumes during download instead of waiting for the
job to complete. Requires unrar on PATH. Falls back to normal
post-processing if articles fail or unrar is unavailable.